@@ -23,7 +23,12 @@ import zipfile
 
 import numpy as np
 import numpy.typing as npt
-import pydicom
+
+try:
+    import pydicom
+except (ModuleNotFoundError, ImportError) as imp_exn:
+    msg = f"pydicom must be installed to use {__name__}."
+    raise RuntimeError(msg) from imp_exn
 
 import medio.base as miob
 import medio.exceptions as mioe
@@ -132,8 +137,8 @@ class SortedSlices:
     def check_nonuniformity(
         self,
         *,
-        max_nonuniformity: float = 5e-4,
-        fail_outside_max_nonuniformity: bool = True,
+        max_nonuniformity: builtins.float = 5e-4,
+        fail_outside_max_nonuniformity: builtins.bool = True,
     ) -> None:
         if len(self) > 1:
             diffs = np.diff(self.positions)
@@ -187,8 +192,8 @@ class DICOMDir:
         datasets: typing.Sequence[pydicom.Dataset],
         *,
         paths: typing.Optional[typing.Sequence[miot.PathLike]] = None,
-        max_nonuniformity: float = 5e-4,
-        fail_outside_max_nonuniformity: bool = True,
+        max_nonuniformity: builtins.float = 5e-4,
+        fail_outside_max_nonuniformity: builtins.bool = True,
         remove_anomalous_images: builtins.bool = True,
     ) -> DICOMDir:
         if not datasets:
@@ -217,8 +222,8 @@ class DICOMDir:
         cls: typing.Type[DICOMDir],
         dicom_path: miot.PathLike | typing.Iterable[miot.PathLike],
         *,
-        max_nonuniformity: float = 5e-4,
-        fail_outside_max_nonuniformity: bool = True,
+        max_nonuniformity: builtins.float = 5e-4,
+        fail_outside_max_nonuniformity: builtins.bool = True,
         remove_anomalous_images: builtins.bool = True,
         defer_size: builtins.str | builtins.int | None = "1 KB",
     ) -> DICOMDir:
@@ -250,8 +255,8 @@ class DICOMDir:
         cls: typing.Type[DICOMDir],
         data_stream: typing.BinaryIO,
         *,
-        max_nonuniformity: float = 5e-4,
-        fail_outside_max_nonuniformity: bool = True,
+        max_nonuniformity: builtins.float = 5e-4,
+        fail_outside_max_nonuniformity: builtins.bool = True,
         remove_anomalous_images: builtins.bool = True,
         **zip_kwargs: typing.Any,
     ) -> DICOMDir:
@@ -377,8 +382,8 @@ class DICOMImage(miob.ImageBase):
         *,
         rescale: typing.Optional[builtins.bool] = None,
         rescale_dtype: npt.DTypeLike = np.float32,
-        max_nonuniformity: float = 5e-4,
-        fail_outside_max_nonuniformity: bool = True,
+        max_nonuniformity: builtins.float = 5e-4,
+        fail_outside_max_nonuniformity: builtins.bool = True,
         remove_anomalous_images: builtins.bool = True,
     ) -> DICOMImage:
         dicomdir = DICOMDir.from_path(
@@ -394,8 +399,8 @@ class DICOMImage(miob.ImageBase):
         cls: typing.Type[DICOMImage],
         data_stream: typing.BinaryIO,
         *,
-        max_nonuniformity: float = 5e-4,
-        fail_outside_max_nonuniformity: bool = True,
+        max_nonuniformity: builtins.float = 5e-4,
+        fail_outside_max_nonuniformity: builtins.bool = True,
         remove_anomalous_images: builtins.bool = True,
         rescale: typing.Optional[builtins.bool] = None,
         rescale_dtype: npt.DTypeLike = np.float32,
