@@ -19,9 +19,9 @@ import numpy.typing as npt
 try:
     import nibabel as nib
     import SimpleITK as sitk
-except (ModuleNotFoundError, ImportError) as e:
+except (ModuleNotFoundError, ImportError) as imp_exn:
     msg = f"NiBabel and SimpleITK must be installed to use {__name__}."
-    raise RuntimeError(msg) from e
+    raise RuntimeError(msg) from imp_exn
 
 import medio.base as miob
 import medio.dicom as miod
@@ -178,8 +178,8 @@ class Image(miob.ImageBase):
         cls: typing.Type[Image],
         data_stream: typing.BinaryIO,
         *,
-        max_nonuniformity: float = 5e-4,
-        fail_outside_max_nonuniformity: bool = True,
+        max_nonuniformity: builtins.float = 5e-4,
+        fail_outside_max_nonuniformity: builtins.bool = True,
         remove_anomalous_images: builtins.bool = True,
         rescale: typing.Optional[builtins.bool] = None,
         rescale_dtype: npt.DTypeLike = np.float32,
